@@ -6,15 +6,17 @@ use warnings;
 
 =head1 NAME
 
-CLI::latextable - The great new CLI::latextable!
+CLI::latextable - Copy-paste almost any kind of table such as Excel 
+worksheet region or SQL output, you get the LaTeX commands to produce 
+same table.
 
 =head1 VERSION
 
-Version 0.114
+Version 0.115
 
 =cut
 
-our $VERSION = '0.114';
+our $VERSION = '0.115';
 
 
 =head1 SUPPORT
